@@ -11,10 +11,10 @@ data_frame <- function(...) {
 # do we have a stan-model?
 is.stan <- function(x) inherits(x, c("stanreg", "stanfit", "brmsfit"))
 
-
-#' @importFrom dplyr quos select
+#' @importFrom rlang is_empty
+#' @importFrom dplyr select
 get_dot_data <- function(x, qs) {
-  if (isempty(qs))
+  if (rlang::is_empty(qs))
     x
   else
     suppressMessages(dplyr::select(x, !!!qs))
@@ -40,6 +40,8 @@ is.num.chr <- function(x, na.rm = FALSE) {
   !anyNA(suppressWarnings(as.numeric(x)))
 }
 
+
+#' @importFrom purrr compact
 isempty <- function(x, first.only = TRUE) {
   # do we have a valid vector?
   if (!is.null(x)) {
@@ -58,14 +60,19 @@ isempty <- function(x, first.only = TRUE) {
       })
       # return result for multiple elements of character vector
       if (first.only) {
-        return(unname(zero_len)[1])
+        zero_len <- isTRUE(zero_len[1])
+        if (length(x) > 0) x <- x[!is.na(x)][1]
       } else {
         return(unname(zero_len))
       }
       # we have a non-character vector here. check for length
+    } else if (is.list(x)) {
+      x <- purrr::compact(x)
+      zero_len <- length(x) == 0
     } else {
       zero_len <- length(x) == 0
     }
   }
-  return(is.null(x) || zero_len || is.na(x))
+
+  any(is.null(x) || zero_len || all(is.na(x)))
 }
